@@ -57,9 +57,10 @@
 
 #include "extinit.h"
 
-/* XTest events are sent during request processing and may be interruped by
+/* XTest events are sent during request processing and may be interrupted by
  * a SIGIO. We need a separate event list to avoid events overwriting each
- * other's memory */
+ * other's memory.
+ */
 static InternalEvent *xtest_evlist;
 
 /**
@@ -127,7 +128,7 @@ ProcXTestCompareCursor(ClientPtr client)
     else if (stuff->cursor == XTestCurrentCursor)
         pCursor = GetSpriteCursor(ptr);
     else {
-        rc = dixLookupResourceByType((pointer *) &pCursor, stuff->cursor,
+        rc = dixLookupResourceByType((void **) &pCursor, stuff->cursor,
                                      RT_CURSOR, client, DixReadAccess);
         if (rc != Success) {
             client->errorValue = stuff->cursor;
@@ -421,7 +422,7 @@ ProcXTestFakeInput(ClientPtr client)
     case KeyPress:
     case KeyRelease:
         nevents =
-            GetKeyboardEvents(xtest_evlist, dev, type, ev->u.u.detail, NULL);
+            GetKeyboardEvents(xtest_evlist, dev, type, ev->u.u.detail);
         break;
     }
 
@@ -468,7 +469,7 @@ ProcXTestDispatch(ClientPtr client)
     }
 }
 
-static int
+static int _X_COLD
 SProcXTestGetVersion(ClientPtr client)
 {
     REQUEST(xXTestGetVersionReq);
@@ -479,7 +480,7 @@ SProcXTestGetVersion(ClientPtr client)
     return ProcXTestGetVersion(client);
 }
 
-static int
+static int _X_COLD
 SProcXTestCompareCursor(ClientPtr client)
 {
     REQUEST(xXTestCompareCursorReq);
@@ -491,7 +492,7 @@ SProcXTestCompareCursor(ClientPtr client)
     return ProcXTestCompareCursor(client);
 }
 
-static int
+static int _X_COLD
 XTestSwapFakeInput(ClientPtr client, xReq * req)
 {
     int nev;
@@ -501,10 +502,11 @@ XTestSwapFakeInput(ClientPtr client, xReq * req)
 
     nev = ((req->length << 2) - sizeof(xReq)) / sizeof(xEvent);
     for (ev = (xEvent *) &req[1]; --nev >= 0; ev++) {
+        int evtype = ev->u.u.type & 0x177;
         /* Swap event */
-        proc = EventSwapVector[ev->u.u.type & 0177];
+        proc = EventSwapVector[evtype];
         /* no swapping proc; invalid event type? */
-        if (!proc || proc == NotImplemented) {
+        if (!proc || proc == NotImplemented || evtype == GenericEvent) {
             client->errorValue = ev->u.u.type;
             return BadValue;
         }
@@ -514,7 +516,7 @@ XTestSwapFakeInput(ClientPtr client, xReq * req)
     return Success;
 }
 
-static int
+static int _X_COLD
 SProcXTestFakeInput(ClientPtr client)
 {
     int n;
@@ -528,7 +530,7 @@ SProcXTestFakeInput(ClientPtr client)
     return ProcXTestFakeInput(client);
 }
 
-static int
+static int _X_COLD
 SProcXTestGrabControl(ClientPtr client)
 {
     REQUEST(xXTestGrabControlReq);
@@ -538,7 +540,7 @@ SProcXTestGrabControl(ClientPtr client)
     return ProcXTestGrabControl(client);
 }
 
-static int
+static int _X_COLD
 SProcXTestDispatch(ClientPtr client)
 {
     REQUEST(xReq);
